#!/bin/sh

case $1 in
  clean)
    if [ ! -f "COPYING" ] ; then
      wget -c https://www.gnu.org/licenses/old-licenses/gpl-2.0.md -O COPYING
    fi
    for i in NEWS README AUTHORS ChangeLog; do
      if [ ! -f "$i" ]; then
        touch $i
      fi
    done
    rm -fv config.status config.h Makefile.reset missing stamp-h1
    rm -fv ar-lib config.h.in depcomp libtool main.c config.guess config.sub install-sh ltmain.sh
    rm -fv aclocal.m4 config.in config.in~ config.log configure Makefile.in
    find ./ -name "*.in" -type f -exec rm -fv {} \;
    find ./ -name "*~" -type f -exec rm -fv {} \;
    find ./ -name "Makefile" -type f -exec rm -fv {} \;
    rm -rfv autom4te.cache build-aux Debug
    find ./ -name "*.cache" -type f -exec rm -fv {} \;
    find ./ -name "*.cache" -type d -exec rm -rfv {} \;
    ;;
  build)
    CWD=$PWD
    shift
    builddir=${1:-build}
    if [ ! -f configure ] ; then
      autoreconf -vif
    fi
    if [ -f configure ] ; then
      if [ -d ../${builddir} ] ; then
        rm -rfv ../${builddir}
      fi
      mkdir -p ../${builddir}
      (cd ../${builddir}/; ${CWD}/configure; make)
    fi
    ;;
  conf)
    autoreconf -vif
    ;;
  dist)
    shift
    builddir=${1:-build}
    $0 build ${builddir}
    (cd ../${builddir}; make dist)
    ;;
  confbuild)
    shift
    builddir=${1:-build}
    $0 clean
    $0 conf
    $0 build ${builddir}
    ;;
  gplv2)
    if [ -n "$2" ] ; then
        if [ -f "$2" ] ; then
            echo "$2 found!"
            exit 1
        fi
        bname=$(basename $2)
        cat > "$2" <<EOF
/* -*- Mode: C; indent-tabs-mode: t; c-basic-offset: 8; tab-width: 8 -*-  */
/* $bname
 *
 * Copyright (C) 2019  Giam Teck Choon <choon@choon.net>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 * 02110-1301, USA.
 */

EOF
    fi
    ;;
  *) echo "$0: clean|build|conf|dist|confbuild|gplv2"
    ;;
esac
